@@ -13,6 +13,3 @@ from pwnlib.log import console, rootlogger
 context.terminal = ["kitty", "-e", "sh", "-c"]  # pylint: disable=assigning-non-slot
 
 console.setLevel(CRITICAL)
-
-for h in rootlogger.handlers:
-    rootlogger.removeHandler(h)
