@@ -162,12 +162,13 @@ class PW:
             raise FileNotFoundError(f"{self.binary} is not a file")
         elif self.binary is not None:
             self.elf = ELF(str(self.binary.resolve()), checksec=False)
-            self.libc = self.elf.libc
             self.libs = {}
 
             for lib in self.elf.libs:
                 if (lname := Path(lib).name) != self.binary.name:
                     self.libs[lname] = ELF(lib, checksec=False)
+                    if "libc" in lname.lower():
+                        self.libc = self.libs[lname]
 
         self.addr = addr
         self.port = port
@@ -231,15 +232,15 @@ class PW:
         """
         Check the security of the binary.
         """
-        if self.elf is not None:
-            for lib, elf in self.libs.items():
-                if not elf != self.elf:
-                    l.info(f"Checksec info for {lib}:")
-                    for ln in elf.checksec().splitlines():
-                        l.info(ln)
-                l.info(f"Checksec info for main object {self.binary.name}:")
-                for ln in self.elf.checksec().splitlines():
+        for lib, elf in self.libs.items():
+            if elf.path != self.elf.path:
+                l.info(f"Checksec info for library: {lib}")
+                for ln in elf.checksec().splitlines():
                     l.info(ln)
+        if self.elf is not None:
+            l.info(f"Checksec info for main object: {self.binary.name}")
+            for ln in self.elf.checksec().splitlines():
+                l.info(ln)
 
     # Printer proxy methods
 
